@@ -1,4 +1,3 @@
-import time
 from os import system
 from pathlib import Path
 from urllib.parse import urlparse
@@ -55,12 +54,6 @@ def cli():  # pragma: no cover
 
         the-well-maintained-test package the-well-maintained-test
 
-    URL is a url to a github repository you'd like to check, for example:
-
-        the-well-maintained-test url 'https://github.com/ryancheley/the-well-maintained-test'
-
-    Note: URL was deprecated and replaced with package starting in v0.9.0
-
     """
     pass
 
@@ -83,123 +76,6 @@ def auth(auth: str) -> None:  # pragma: no cover
     save_auth(auth)
 
 
-@cli.command()
-@click.option(
-    "-u",
-    "--url",
-    type=click.Path(file_okay=True, dir_okay=False, allow_dash=False),
-    help="GitHub URL to use",
-)
-@click.option(
-    "-b",
-    "--branch",
-    type=click.STRING,
-    help="Branch to check",
-)
-@click.option(
-    "-p",
-    "--progress",
-    type=click.BOOL,
-    default=True,
-    help="Show progress on test check",
-)
-@click.option(
-    "-o",
-    "--output",
-    type=click.Choice(["html", "txt"]),
-    help="Show progress on test check",
-)
-def url(url: str, branch: str, progress: bool, output: str) -> None:  # pragma: no cover
-    "URL to a github repository you'd like to check. This method will be deprecated in v0.9.0"
-    if url[-1] == "/":
-        url = url.strip("/")
-
-    with open(Path(pkg_resources.resource_filename(__name__, str(Path("data").joinpath("questions.toml"))))) as file:
-        questions = toml.load(file)
-
-    parse_object = urlparse(url)
-    author = parse_object.path.split("/")[-2]
-    package = parse_object.path.split("/")[-1]
-    api_url = f"https://api.github.com/repos/{author}/{package}"
-    if not branch:
-        default_branch = requests.get(api_url).json().get("default_branch")
-    else:
-        default_branch = branch
-    commits_url = f"https://api.github.com/repos/{author}/{package}/commits/{default_branch}"
-    workflows_url = f"https://api.github.com/repos/{author}/{package}/actions/workflows"
-    ci_status_url = f"https://api.github.com/repos/{author}/{package}/actions/runs"
-    bugs_url = f"https://api.github.com/repos/{author}/{package}/issues?labels=bug"
-    pypi_url = f"https://pypi.org/pypi/{package}/json"
-    tree_url = f"https://api.github.com/repos/{author}/{package}/git/trees/{default_branch}?recursive=1"
-
-    vulnerabilities = get_vulnerabilities(pypi_url)
-    if vulnerabilities > 0:
-        console.rule("[bold red]Vulnerabilities detected!!!")
-        console.print(
-            Padding(f"There are {vulnerabilities} vulnerabilities in this package", answer_padding_style, style=warning_style)
-        )
-        console.rule()
-
-    console.rule()
-
-    console.print(
-        Padding(
-            """
-            This method has been deprecated in v0.9.0.
-            It is now an optional.
-            Please use --name instead.
-            """,
-            answer_padding_style,
-            style=warning_style,
-        )
-    )
-
-    console.rule()
-    time.sleep(3)
-
-    console.print(questions.get("question").get("1").get("question_text"), style=question_style)
-    console.print(Padding(production_ready_check(pypi_url), answer_padding_style, style=answer_style))
-
-    console.print(questions.get("question").get("2").get("question_text"), style=question_style)
-    console.print(Padding(documentation_exists(pypi_url), answer_padding_style, style=answer_style))
-
-    console.print(questions.get("question").get("3").get("question_text"), style=question_style)
-    console.print(Padding(change_log_check(pypi_url), answer_padding_style, style=answer_style))
-
-    console.print(questions.get("question").get("4").get("question_text"), style=question_style)
-    console.print(Padding(bug_responding(bugs_url, headers), answer_padding_style, style=answer_style))
-
-    console.print(questions.get("question").get("5").get("question_text"), style=question_style)
-    console.print(Padding(check_tests(tree_url, headers, progress), special_answer_padding_style, style=answer_style))
-
-    console.print(questions.get("question").get("6").get("question_text"), style=question_style)
-    console.print(Padding(language_check(pypi_url), answer_padding_style, style=answer_style))
-
-    console.print(questions.get("question").get("7").get("question_text"), style=question_style)
-    console.print(Padding(framework_check(pypi_url), answer_padding_style, style=answer_style))
-
-    console.print(questions.get("question").get("8").get("question_text"), style=question_style)
-    console.print(Padding(ci_setup(workflows_url, headers), answer_padding_style, style=answer_style))
-
-    console.print(questions.get("question").get("9").get("question_text"), style=question_style)
-    console.print(Padding(ci_passing(ci_status_url, headers), answer_padding_style, style=answer_style))
-
-    console.print(questions.get("question").get("10").get("question_text"), style=question_style)
-    console.print(Padding(well_used(api_url, headers), answer_padding_style, style=answer_style))
-
-    console.print(questions.get("question").get("11").get("question_text"), style=question_style)
-    console.print(Padding(commit_in_last_year(commits_url, headers), answer_padding_style, style=answer_style))
-
-    console.print(questions.get("question").get("12").get("question_text"), style=question_style)
-    console.print(Padding(release_in_last_year(pypi_url), answer_padding_style, style=answer_style))
-
-    if output == "html":
-        console.save_html("output.html")
-
-    if output == "txt":
-        console.save_text("output.txt")
-
-
 @cli.command()
 @click.option(
     "-n",
@@ -334,10 +210,7 @@ def package(package: str, branch: str, progress: bool, output: str) -> None:  #
         name (str): The name of the Package from PyPi
     """
     pypi_url = f"https://pypi.org/pypi/{package}/json"
-    project_urls = requests.get(pypi_url).json().get("info").get("project_urls")
-    for _, v in project_urls.items():
-        if urlparse(v).netloc == "github.com" and len(urlparse(v).path.split("/")) == 3:
-            url = v
+    url = _get_package_github_url(package)[1]
 
     "url to a github repository you'd like to check"
     if url[-1] == "/":
